# renkon

|         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|---------| |
| CI/CD   | [![Tests](https://github.com/DylanLukes/renkon/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/DylanLukes/renkon/actions/workflows/test.yml)                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| Package | [![PyPI - Version](https://img.shields.io/pypi/v/renkon.svg)](https://pypi.org/project/renkon) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/renkon.svg)](https://pypi.org/project/renkon)                                                                                                                                                                                                                                                                                                                                                                                                          |
| Meta    | [![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch) [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v0.json)](https://github.com/charliermarsh/ruff) [![Code Style - Black](https://img.shields.io/badge/code%20style-Black-333.svg)](https://github.com/psf/black) [![types - Mypy](https://img.shields.io/badge/types-Mypy-1F5082.svg)](https://github.com/python/mypy) [![License - MIT](https://img.shields.io/badge/license-BSD-default.svg)](https://spdx.org/licenses/) |

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install renkon
```

## License

`renkon` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
